# Wagtail Site Check Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- ...

## [0.0.3] - 2024-03-06

- Make `ALLOWED_WAGTAIL_SITES` optional, use `ALLOWED_HOSTS` as default.

## [0.0.2] - 2023-10-25

- Fix readme
- Fix templates

## [0.0.1] - 2023-10-24

- Initial release.


[unreleased]: https://github.com/wagtail-nest/wagtail-font-awesome-svg/compare/0.0.2...HEAD
[0.0.2]: https://github.com/allcaps/wagtail-site-check/compare/0.0.2...0.0.3
[0.0.2]: https://github.com/allcaps/wagtail-site-check/compare/0.0.1...0.0.2
[0.0.1]: https://github.com/allcaps/wagtail-site-check/compare/475414d613d433b7ac10e1dbb605f5d6ad83a77b...0.0.1
